package org.gcube.data_catalogue.grsf_publish_ws.json;

import org.gcube.data_catalogue.grsf_publish_ws.utils.groups.Source;
import org.gcube.data_catalogue.grsf_publish_ws.utils.groups.Status;
import org.gcube.data_catalogue.grsf_publish_ws.utils.groups.Type;

import com.fasterxml.jackson.annotation.JsonProperty;

/**
 * Information that both Stock and Fishery must contain
 * @author Costantino Perciante at ISTI-CNR (costantino.perciante@isti.cnr.it)
 */
public class Common {

	@JsonProperty("description")
	private String description;

	@JsonProperty("license")
	private String license;

	@JsonProperty("author")
	private String author; // this will be filled with the username of the token's owner

	@JsonProperty("version")
	private long version;

	@JsonProperty("author_contact")
	private String authorContact;

	@JsonProperty("maintainer")
	private String maintainer;

	@JsonProperty("maintainer_contact")
	private String maintainerContact;

	@JsonProperty("catches_or_landings")
	private String catchesOrLandings;

	@JsonProperty("database_sources")
	private Source databaseSources;

	@JsonProperty("source_of_information")
	private String sourceOfInformation;

	@JsonProperty("data_owner")
	private String dataOwner;

	@JsonProperty("type")
	private Type type;

	@JsonProperty("status")
	private Status status;

	public Common() {
		super();
	}

	/**
	 * @param description
	 * @param license
	 * @param author
	 * @param version
	 * @param authorContact
	 * @param maintainer
	 * @param maintainerContact
	 * @param catchesOrLandings
	 * @param databaseSources
	 * @param sourceOfInformation
	 * @param dataOwner
	 * @param type
	 * @param status
	 */
	public Common(String description, String license, String author,
			long version, String authorContact, String maintainer,
			String maintainerContact, String catchesOrLandings,
			Source databaseSources, String sourceOfInformation,
			String dataOwner, Type type, Status status) {
		super();
		this.description = description;
		this.license = license;
		this.author = author;
		this.version = version;
		this.authorContact = authorContact;
		this.maintainer = maintainer;
		this.maintainerContact = maintainerContact;
		this.catchesOrLandings = catchesOrLandings;
		this.databaseSources = databaseSources;
		this.sourceOfInformation = sourceOfInformation;
		this.dataOwner = dataOwner;
		this.type = type;
		this.status = status;
	}

	public String getDescription() {
		return description;
	}

	public void setDescription(String description) {
		this.description = description;
	}

	public String getLicense() {
		return license;
	}

	public void setLicense(String license) {
		this.license = license;
	}

	public String getAuthor() {
		return author;
	}

	public void setAuthor(String author) {
		this.author = author;
	}

	public long getVersion() {
		return version;
	}

	public void setVersion(long version) {
		this.version = version;
	}

	public String getAuthorContact() {
		return authorContact;
	}

	public void setAuthorContact(String authorContact) {
		this.authorContact = authorContact;
	}

	public String getMaintainer() {
		return maintainer;
	}

	public void setMaintainer(String maintainer) {
		this.maintainer = maintainer;
	}

	public String getMaintainerContact() {
		return maintainerContact;
	}

	public void setMaintainerContact(String maintainerContact) {
		this.maintainerContact = maintainerContact;
	}

	public String getCatchesOrLandings() {
		return catchesOrLandings;
	}

	public void setCatchesOrLandings(String catchesOrLandings) {
		this.catchesOrLandings = catchesOrLandings;
	}

	public Source getDatabaseSources() {
		return databaseSources;
	}

	public void setDatabaseSources(Source databaseSources) {
		this.databaseSources = databaseSources;
	}

	public String getSourceOfInformation() {
		return sourceOfInformation;
	}

	public void setSourceOfInformation(String sourceOfInformation) {
		this.sourceOfInformation = sourceOfInformation;
	}

	public String getDataOwner() {
		return dataOwner;
	}

	public void setDataOwner(String dataOwner) {
		this.dataOwner = dataOwner;
	}

	public Type getType() {
		return type;
	}

	public void setType(Type type) {
		this.type = type;
	}

	public Status getStatus() {
		return status;
	}

	public void setStatus(Status status) {
		this.status = status;
	}

	@Override
	public String toString() {
		return "Common [description=" + description + ", license=" + license
				+ ", author=" + author + ", version=" + version
				+ ", authorContact=" + authorContact + ", maintainer="
				+ maintainer + ", maintainerContact=" + maintainerContact
				+ ", catchesOrLandings=" + catchesOrLandings
				+ ", databaseSources=" + databaseSources
				+ ", sourceOfInformation=" + sourceOfInformation
				+ ", dataOwner=" + dataOwner + ", type=" + type + ", status="
				+ status + "]";
	}
}
